==> kdegraphics-3.4.2.tar.bz2: kdegraphics-3.4.2/ksvg/dom/SVGElementInstanceList.cc <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include "SVGElementInstanceList.h"
#include "SVGElementInstanceListImpl.h"
#include "SVGElementInstance.h"

using namespace KSVG;

SVGElementInstanceList::SVGElementInstanceList()
{
	impl = new SVGElementInstanceListImpl();
	impl->ref();
}

SVGElementInstanceList::SVGElementInstanceList(const SVGElementInstanceList &other) : impl(0)
{
	(*this) = other;
}

SVGElementInstanceList &SVGElementInstanceList::operator=(const SVGElementInstanceList &other)
{
	if(impl == other.impl)
		return *this;

	if(impl)
		impl->deref();

	impl = other.impl;

	if(impl)
		impl->ref();

	return *this;
}

SVGElementInstanceList::SVGElementInstanceList(SVGElementInstanceListImpl *other)
{
	impl = other;
	if(impl)
		impl->ref();
}

SVGElementInstanceList::~SVGElementInstanceList()
{
	if(impl)
		impl->deref();
}

unsigned long SVGElementInstanceList::length() const
{
	if(!impl) return 0;
	return impl->length();
}

SVGElementInstance SVGElementInstanceList::item(unsigned long index)
{
	if(!impl) return SVGElementInstance(0);
	return SVGElementInstance(impl->item(index));
}

// vim:ts=4:noet

==> kdegraphics-3.5.10.tar.bz2: kdegraphics-3.5.10/ksvg/dom/SVGElementInstanceList.cc <==
/*
    Copyright (C) 2001-2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "SVGElementInstanceList.h"
#include "SVGElementInstanceListImpl.h"
#include "SVGElementInstance.h"

using namespace KSVG;

SVGElementInstanceList::SVGElementInstanceList()
{
	impl = new SVGElementInstanceListImpl();
	impl->ref();
}

SVGElementInstanceList::SVGElementInstanceList(const SVGElementInstanceList &other) : impl(0)
{
	(*this) = other;
}

SVGElementInstanceList &SVGElementInstanceList::operator=(const SVGElementInstanceList &other)
{
	if(impl == other.impl)
		return *this;

	if(impl)
		impl->deref();

	impl = other.impl;

	if(impl)
		impl->ref();

	return *this;
}

SVGElementInstanceList::SVGElementInstanceList(SVGElementInstanceListImpl *other)
{
	impl = other;
	if(impl)
		impl->ref();
}

SVGElementInstanceList::~SVGElementInstanceList()
{
	if(impl)
		impl->deref();
}

unsigned long SVGElementInstanceList::length() const
{
	if(!impl) return 0;
	return impl->length();
}

SVGElementInstance SVGElementInstanceList::item(unsigned long index)
{
	if(!impl) return SVGElementInstance(0);
	return SVGElementInstance(impl->item(index));
}

// vim:ts=4:noet
